@@ -54,6 +54,7 @@
 (defun darwin-fallback-library-path ()
   (or (explode-path-environment-variable "DYLD_FALLBACK_LIBRARY_PATH")
       (list (merge-pathnames #p"lib/" (user-homedir-pathname))
+            #p"/opt/local/lib/"
             #p"/usr/local/lib/"
             #p"/usr/lib/")))
 
@@ -317,7 +318,7 @@ ourselves."
   (handler-case
       (values (%load-foreign-library name path)
               (pathname path))
-    (error (error)
+    (simple-error (error)
       (let ((dirs (parse-directories *foreign-library-directories*)))
         (if-let (file (find-file path (append search-path dirs)))
           (handler-case
@@ -327,12 +328,12 @@ ourselves."
               (report-simple-error name error)))
           (report-simple-error name error))))))
 
-(defun try-foreign-library-alternatives (name library-list)
+(defun try-foreign-library-alternatives (name library-list &optional search-path)
   "Goes through a list of alternatives and only signals an error when
 none of alternatives were successfully loaded."
   (dolist (lib library-list)
     (multiple-value-bind (handle pathname)
-        (ignore-errors (load-foreign-library-helper name lib))
+        (ignore-errors (load-foreign-library-helper name lib search-path))
       (when handle
         (return-from try-foreign-library-alternatives
           (values handle pathname)))))
@@ -357,7 +358,7 @@ This will need to be extended as we test on more OSes."
 (defun load-foreign-library-helper (name thing &optional search-path)
   (etypecase thing
     ((or pathname string)
-     (load-foreign-library-path (filter-pathname name) thing search-path))
+     (load-foreign-library-path name (filter-pathname thing) search-path))
     (cons
      (ecase (first thing)
        (:framework (load-darwin-framework name (second thing)))
@@ -369,7 +370,7 @@ This will need to be extended as we test on more OSes."
                             (second thing)
                             (default-library-suffix))))
           (load-foreign-library-path name library-path search-path)))
-       (:or (try-foreign-library-alternatives name (rest thing)))))))
+       (:or (try-foreign-library-alternatives name (rest thing) search-path))))))
 
 (defun %do-load-foreign-library (library search-path)
   (flet ((%do-load (lib name spec)
