@@ -264,6 +264,20 @@
 
 ;;;# Calling varargs functions
 
+(defcfun "sum_double_arbitrary" :double (n :int) &rest)
+
+(deftest defcfun.varargs.nostdlib
+    (sum-double-arbitrary
+     26
+     :double 3.14d0 :double 3.14d0 :double 3.14d0 :double 3.14d0
+     :double 3.14d0 :double 3.14d0 :double 3.14d0 :double 3.14d0
+     :double 3.14d0 :double 3.14d0 :double 3.14d0 :double 3.14d0
+     :double 3.14d0 :double 3.14d0 :double 3.14d0 :double 3.14d0
+     :double 3.14d0 :double 3.14d0 :double 3.14d0 :double 3.14d0
+     :double 3.14d0 :double 3.14d0 :double 3.14d0 :double 3.14d0
+     :double 3.14d0 :double 3.14d0)
+  81.64d0)
+
 (defcfun "sprintf" :int
   "sprintf docstring"
   (str (:pointer :char))
@@ -455,7 +469,7 @@
 ;;; regression test: defining an undefined foreign function should only
 ;;; throw some sort of warning, not signal an error.
 
-#+(or cmu (and sbcl (or (not linkage-table) win32)))
+#+(or cmucl (and sbcl win32))
 (pushnew 'defcfun.undefined rt::*expected-failures*)
 
 (deftest defcfun.undefined
